@@ -122,7 +122,7 @@ void* item_anisotropic_smoothing() {
     }
     veloc*=40.0f/betamax;
     images[1]+=veloc;
-    images[0].draw_text(0,0,"iter %u",white,black,1,11,iter);
+    images[0].draw_text(4,4,"Iteration : %u ",white,black,1,13,iter);
     disp.resize(false).display(images);
   }
   return 0;
@@ -161,7 +161,7 @@ void* item_gamma_correction() {
     const CImg<float> hist = visu[0].get_histogram(50,0,255);
     visu[1].fill(0).draw_text(50,5,"Gamma = %.3g",white,0,1,24,gamma).
       draw_graph(hist,green,1,3,0,20000,0).draw_graph(hist,yellow,1,2,0,20000,0).
-      draw_axis(0,256,20000,0,white,0.7f);
+      draw_axes(0,256,20000,0,white,0.7f);
     const int xb = (int)(50 + gamma*150);
     visu[1].draw_grid(20,20,0,0,false,false,white,0.3f,0xCCCCCCCC,0xCCCCCCCC).
       draw_rectangle(51,31,xb-1,39,blue2).draw_rectangle(50,30,xb,30,blue).draw_rectangle(xb,30,xb,40,blue).
@@ -236,7 +236,7 @@ void* item_filled_triangles() {
     }
 
     // Display current animation framerate, and refresh display window.
-    img.draw_text(5,5,"%u frames/s",white,0,0.5f,11,(unsigned int)disp.frames_per_second());
+    img.draw_text(5,5,"%u frames/s",white,0,0.5f,13,(unsigned int)disp.frames_per_second());
     img0.resize(disp.display(img).resize(false).wait(20));
     if (++num>100) num = 100;
 
@@ -282,14 +282,14 @@ void* item_mandelbrot_explorer() {
         const unsigned char white[] = { 255, 255, 255 };
         static CImg<unsigned char>
           help = CImg<unsigned char>().draw_text(0,0,"\n"
-                                                 " Use mouse to zoom on desired region. \n"
-                                                 " H             Show/Hide help \n"
-                                                 " PAD 1...9       Fractal navigation \n"
-                                                 " PAD +/-       Zoom/Unzoom \n"
-                                                 " SPACE         Set/Disable color smoothing \n"
-                                                 " ENTER         Switch Mandelbrot/Julia sets \n"
-                                                 " Arrows        Change set parameterization \n"
-                                                 " Page UP/DOWN  Add/Reduce iteration numbers \n\n",
+                                                 "  Use mouse to zoom on desired region.  \n"
+                                                 "  H             Show/Hide help  \n"
+                                                 "  PAD 1...9       Fractal navigation  \n"
+                                                 "  PAD +/-       Zoom/Unzoom  \n"
+                                                 "  SPACE         Set/Disable color smoothing  \n"
+                                                 "  ENTER         Switch Mandelbrot/Julia sets  \n"
+                                                 "  Arrows        Change set parameterization  \n"
+                                                 "  Page UP/DOWN  Add/Reduce iteration numbers  \n\n",
                                                  white);
         help.draw_rectangle(2,2,help.width() - 3,help.height() - 3,white,1,~0U);
         img.draw_image(img.width() - help.width(),help,0.7f);
@@ -432,7 +432,7 @@ void* item_soccer_bobs() {
 // Item : Bump Effect
 //--------------------
 void* item_bump() {
-  CImg<float> logo = CImg<>(56,32,1,1,0).draw_text(9,5,"I Love\n CImg!",CImg<>::vector(255).data()).
+  CImg<float> logo = CImg<>(56,32,1,1,0).draw_text(12,3,"I Love\nCImg !",CImg<>::vector(255).data()).
     resize(-800,-800,1,1,3).blur(6).normalize(0,255);
   logo+=CImg<>(logo.width(),logo.height(),1,1,0).noise(80,1).deriche(2,0,'y',false).deriche(10,0,'x',false);
   CImgList<float> grad = logo.get_gradient();
@@ -481,7 +481,7 @@ void* item_bouncing_bubble() {
       draw_ellipse((int)(xm + 0.2*r1*u),(int)(ym - 0.2*r2*u),r1/2,r2/2,0,col3).
       draw_ellipse((int)(xm + 0.3*r1*u),(int)(ym - 0.3*r2*u),r1/4,r2/4,0,col4).
       draw_image(0,img.height() - 40,img.get_crop(0,img.height() - 80,img.width() - 1,img.height() - 40).mirror('y'),0.45f).
-      draw_text(xm - 60,(int)(ym - r2 - 25),"Bubble (%d,%d)",white,0,1,17,xm,ym);
+      draw_text(xm - 70,(int)(ym - r2 - 30),"Bubble (%d,%d)",white,0,0.7f,24,xm,ym);
     if ((cx+=20*vt*vx)>=img.width()-30 || cx<30) vx = -vx;
     disp.display(img).wait(20);
     if (disp.is_resized()) {
@@ -543,7 +543,7 @@ void* item_virtual_landscape() {
         ymin(x) = cimg::min(ymin(x),y); ymax(x) = cimg::max(ymax(x),y);
       }
     }
-    visu.draw_text(5,5,"%u frames/s",white,0,0.5f,11,(unsigned int)disp.frames_per_second());
+    visu.draw_text(5,5,"%u frames/s",white,0,0.5f,13,(unsigned int)disp.frames_per_second());
     disp.resize(false).display(visu.cut(0,255)).wait(25);
     if (disp.is_keyCTRLLEFT() && disp.is_keyF()) disp.resize(400,300,false).toggle_fullscreen(false);
   }
@@ -638,7 +638,7 @@ void* item_oriented_convolutions() {
     mask.draw_gaussian(0.5f*mask.width(),0.5f*mask.height(),tensor,&value);
     mask/=mask.sum();
     visu[1] = mask.get_resize(img).normalize(0,255).
-      draw_text(2,2,"Angle = %d deg",&value,0,1,11,cimg::mod((int)(angle*180/cimg::PI),360));
+      draw_text(2,2,"Angle = %d deg",&value,0,1,13,cimg::mod((int)(angle*180/cimg::PI),360));
     visu[2] = img.get_convolve(mask);
     disp.resize(disp.window_width(),(int)(disp.height()*disp.window_width()/disp.width()),false).
       display(visu).wait(25);
@@ -693,6 +693,7 @@ void* item_shade_bobs() {
     if (disp.is_resized()) img.resize(disp.resize(false),3);
     if ((disp.key() && !disp.is_keyCTRLLEFT()) || disp.button()) {
       t = 70; if (!(disp.is_keyQ() || disp.is_keyESC())) disp.set_key();
+      disp.set_button();
     }
   }
   return 0;
@@ -729,7 +730,7 @@ void* item_fourier_filtering() {
       visu[0] = nF.FFT(true)[0].normalize(0,255);
     }
     if (disp.is_resized()) disp.resize(disp.window_width(),disp.window_width()/2).display(visu);
-    visu[1] = mag.get_mul(mask).draw_text(5,5,"Freq Min/Max = %d / %d",white,zero,0.6f,11,(int)rmin,(int)rmax);
+    visu[1] = mag.get_mul(mask).draw_text(5,5,"Freq Min/Max = %d / %d",white,zero,0.6f,13,(int)rmin,(int)rmax);
     visu.display(disp);
   }
   return 0;
@@ -761,7 +762,7 @@ void* item_image_zoomer() {
           visu.draw_line(X,0,X,dispz.height() - 1,black).draw_line(0,Y,dispz.width() - 1,Y,black);
         }
       }
-      visu.draw_text(2,2,"Coords (%d,%d)",white,0,1,11,x,y).display(dispz);
+      visu.draw_text(2,2,"Coords (%d,%d)",white,0,1,13,x,y).display(dispz);
     }
     if (disp.button()&1) { factor = (int)(factor/1.5f); if (factor<3) factor = 3; disp.set_button(); redraw = true; }
     if (disp.button()&2) { factor = (int)(factor*1.5f); if (factor>100) factor = 100; disp.set_button(); redraw = true; }
@@ -848,7 +849,7 @@ void* item_blobs_editor() {
       CImg<unsigned int> text;
       text.draw_text(0,0,
                      "CImg Blobs Editor\n"
-                     "-----------------\n\n"
+                     "-----------------------\n\n"
                      "* Left mouse button :\n   Create and Move Blob.\n\n"
                      "* Right mouse button :\n  Remove nearest Blob.\n\n"
                      "* Colors and size of Appearing Blobs\n"
@@ -969,7 +970,7 @@ void* item_3d_metaballs() {
                            rpoints,primitives,
                            colors.get_shared_images(0,primitives.size()-1),
                            4,false,500, 0,0,-500, 0.1f,1.5f).
-        draw_text(5,5,"%u frames/s",white,0,0.5f,11,(unsigned int)disp.frames_per_second()).display(disp.wait(20));
+        draw_text(5,5,"%u frames/s",white,0,0.5f,13,(unsigned int)disp.frames_per_second()).display(disp.wait(20));
     }
     if (disp.is_resized()) disp.resize(false);
     if (disp.is_keyCTRLLEFT() && disp.is_keyF()) disp.resize(512,320,false).toggle_fullscreen(false);
@@ -1024,7 +1025,7 @@ void* item_fireworks() {
       if (remove_particle) { particles.remove(l); colors.remove(l); l--; }
     }
     if (disp.button()&2) cimglist_for(particles,l) if (particles(l,4)>0) particles(l,4)=0.5f;
-    img.draw_text(5,5,"%u frames/s",white,red,0.5f,11,(unsigned int)disp.frames_per_second());
+    img.draw_text(5,5," %u frames/s ",white,red,0.5f,13,(unsigned int)disp.frames_per_second());
     disp.display(img).wait(25);
     if (disp.is_keyCTRLLEFT() && disp.is_keyF()) disp.resize(640,480,false).toggle_fullscreen(false);
     if (disp.is_resized()) disp.resize(disp,false);
@@ -1042,7 +1043,7 @@ void* item_rubber_logo() {
   CImgDisplay disp(CImg<unsigned char>(background).
                    draw_text(10,10,"Please wait, generating rubber object...",white),"[#22] - 3D Rubber Logo");
 
-  CImg<unsigned char> vol = CImg<unsigned char>().draw_text(30,30,"CImg",white,0,1,48).resize(-100,-100,15,1);
+  CImg<unsigned char> vol = CImg<unsigned char>().draw_text(30,30,"CImg",white,0,1,57).resize(-100,-100,15,1);
   for (unsigned int k = 0; k<5; ++k) { vol.get_shared_plane(k).fill(0); vol.get_shared_plane(vol.depth()-1-k).fill(0); }
   vol.resize(vol.width()+30,vol.height()+30,-100,1,0).blur(2).resize(-50,-50);
   CImgList<unsigned int> faces;
@@ -1050,9 +1051,9 @@ void* item_rubber_logo() {
   CImgList<unsigned int> colors(faces.size(),CImg<unsigned char>::vector(100,100,255));
   cimglist_for(colors,l) {
     const float x = (points(faces(l,0),0) + points(faces(l,1),0) + points(faces(l,2),0))/3;
-    if (x<27) colors[l] = CImg<unsigned char>::vector(255,100,100);
-    else { if (x<38) colors[l] = CImg<unsigned char>::vector(200,155,100);
-    else { if (x<53) colors[l] = CImg<unsigned char>::vector(100,255,155);
+    if (x<26) colors[l] = CImg<unsigned char>::vector(255,100,100);
+    else { if (x<37) colors[l] = CImg<unsigned char>::vector(200,155,100);
+    else { if (x<51) colors[l] = CImg<unsigned char>::vector(100,255,155);
     }}}
   faces.reverse_object3d();
   (points.shift_object3d()*=5.5f).is_object3d(faces,true,true);
@@ -1080,7 +1081,7 @@ void* item_rubber_logo() {
           y1 = (l+1)*visu.height()/frames.size()-1;
         cimg_forC(visu,k) visu.get_shared_lines(y0,y1,0,k) = frames[(nb_frame+l)%frames.size()].get_shared_lines(y0,y1,0,k);
       }
-      visu.get_resize(disp,1).draw_text(5,5,"%u frames/s",white,0,0.5f,11,(unsigned int)disp.frames_per_second()).display(disp.wait(20));
+      visu.get_resize(disp,1).draw_text(5,5," %u frames/s ",white,0,0.5f,13,(unsigned int)disp.frames_per_second()).display(disp.wait(20));
     }
     if (disp.is_keyCTRLLEFT() && disp.is_keyF()) disp.resize(300,300,false).toggle_fullscreen(false);
     if (disp.is_resized()) disp.resize();
@@ -1105,18 +1106,18 @@ void* item_image_waves() {
     draw_circle(8,4,2,CImg<unsigned char>::vector(0,128,64).data()).
     draw_circle(8,4,1,CImg<unsigned char>::vector(64,196,128).data());
   CImg<float> uc(img.width()/2,img.height()/2,1,1,0), up(uc), upp(uc);
+  CImgList<float> particles;
   CImgDisplay disp(back,"[#23] - Image Waves (Try mouse buttons!)");
-  CImgList<int> particles;
   for (float alpha = 0.0f, count = 10.0f; !disp.is_closed() && !disp.is_keyQ() && !disp.is_keyESC(); ) {
     if ((disp.button()&1 && disp.mouse_x()>=0) || --count<0) {
-      CImg<int>::vector((int)(cimg::rand()*(img.width()-1)),(int)(cimg::rand()*(img.height()-1)),-200,0).move_to(particles);
+      CImg<>::vector((float)(cimg::rand()*(img.width()-1)),(float)(cimg::rand()*(img.height()-1)),-200,0).move_to(particles);
       count = (float)(cimg::rand()*15);
     }
-    alpha = (disp.mouse_x()>=0 && disp.button()&2)?(float)(disp.mouse_x()*2*cimg::PI/disp.width()):(alpha+0.04f);
+    alpha = (disp.mouse_x()>=0 && disp.button()&2)?(float)(disp.mouse_x()*2*cimg::PI/disp.width()):(alpha+0.02f);
     if (disp.is_keyCTRLLEFT() && disp.is_keyF()) disp.resize(400,300,false).toggle_fullscreen(false);
     cimglist_for(particles,l) {
-      float& z = up(particles(l,0)>>1,particles(l,1)>>1);
-      if ((particles(l,2)+=(particles(l,3)++))>z-10) { z = 250.0f; particles.remove(l--); }
+      float& z = up((int)particles(l,0)>>1,(int)particles(l,1)>>1);
+      if ((particles(l,2)+=(particles(l,3)+=0.5f))>z-10) { z = 250.0f; particles.remove(l--); }
     }
     CImg_3x3(U,float); Upp = Unp = Ucc = Upn = Unn = 0;
     cimg_for3x3(up,x,y,0,0,U,float) uc(x,y) = (Unc+Upc+Ucn+Ucp)/2 - upp(x,y);
@@ -1136,7 +1137,7 @@ void* item_image_waves() {
       rot = CImg<>::rotation_matrix(1.0f,0,0,(float)(cimg::PI/3.0f))*CImg<>::rotation_matrix(0,0,1.0f,alpha),
       rpoints = rot*(points>'x');
     (+back).draw_object3d(back.width()/2.0f,back.height()/2.0f,0,rpoints,faces,colors,opacities,4,false,500.0f,0,0,0,1,1).
-      display(disp.resize(false).wait(20));
+      display(disp.resize(false).wait(30));
   }
   return 0;
 }
@@ -1197,7 +1198,7 @@ void* item_breakout() {
     if (yb>h || N==N0) {
       disp.show_mouse();
       while (!disp.is_closed() && !disp.key() && !disp.button()) {
-        ((visu=visu0)/=2).draw_text(50,visu.height()/2-10,N0?"Game Over !":"Get Ready ?",white,0,1,25).
+        ((visu=visu0)/=2).draw_text(50,visu.height()/2-10,N0?" Game Over !":"Get Ready ?",white,0,1,24).
           display(disp);
         disp.wait();
         if (disp.is_resized()) disp.resize(disp);
@@ -1321,7 +1322,7 @@ void* item_3d_reflection() {
 //------------------------------
 void* item_fisheye_magnification() {
   const unsigned char purple[] = { 255, 0, 255 }, white[] = { 255, 255, 255 }, black[] = { 0, 0, 0 };
-  const CImg<unsigned char> img0 = CImg<unsigned char>(data_logo,555,103,1,3,true).get_resize(-144,-144,1,3,5);
+  const CImg<unsigned char> img0 = CImg<unsigned char>(data_logo,555,103,1,3,true).get_resize(-144,-144,1,3,6);
   CImgDisplay disp(img0,"[#26] - Fish-Eye Magnification");
   int rm = 80, xc = 0, yc = 0, rc = 0;
   CImg<unsigned char> img, res;
@@ -1353,8 +1354,8 @@ void* item_fisheye_magnification() {
   return 0;
 }
 
-// Item : Word puzzle
-//------------------------------
+// Item : Word Puzzle
+//--------------------
 void* item_word_puzzle() {
 
   // Create B&W and color letters
@@ -1364,7 +1365,7 @@ void* item_word_puzzle() {
   char tmptxt[] = { 'A',0 };
   model.fill(255).draw_rectangle(5,5,54,54,gray).blur(3,0).threshold(140).normalize(0,255);
   cimglist_for(letters,l)
-    (letters[l].draw_text(5,2,&(tmptxt[0]='A'+l),white,0,1,64).resize(60,60,1,1,0,0,true).
+    (letters[l].draw_text(5,2,&(tmptxt[0]='A'+l),white,0,1,57).resize(60,60,1,1,0,0,0.5,0.5).
      resize(-100,-100,1,3)|=model).blur(0.5);
   { cimglist_for(cletters,l) {
     CImg<int> tmp = letters[l];
@@ -1402,7 +1403,7 @@ void* item_word_puzzle() {
         }
         refresh_canvas = false;
       }
-      (+canvas).draw_text(360,3,"Elapsed Time : %d",white,0,1,16,timer++).display(disp);
+      (+canvas).draw_text(280,3,"Elapsed Time : %d",white,0,0.7f,24,timer++).display(disp);
 
       if (disp.button()&1) {
         const int mx = disp.mouse_x(), my = disp.mouse_y();
@@ -1430,7 +1431,7 @@ void* item_word_puzzle() {
               cimg_forC(background,k) cimg_forY(letters[0],y)
                 background.get_shared_line(solution(j,2)+y,0,k).
                 draw_image(solution(j,1),0,
-                           (CImg<float>(cletters(solution(j)-'A').get_shared_line(y,0,k))*=2.0*std::cos((y-30.0f)/18)).
+                           (CImg<>(cletters(solution(j)-'A').get_shared_line(y,0,k))*=2.0*std::cos((y-30.0f)/18)).
                            cut(0,255),0.8f);
               current(i,5) = solution(j,3) = 1; refresh_canvas = true;
             }
@@ -1519,7 +1520,7 @@ int main(int argc, char **argv) {
     CImg<unsigned char> back(1,2,1,3,10), fore, text, img;
     back.fillC(0,1,0,10,10,235).resize(320,420,1,3,3).get_shared_channel(2).noise(10,1).draw_plasma();
     back.draw_rectangle(0,y0-7,back.width()-1,y0+20,red);
-    fore.assign(back.width(),50,1,1,0).draw_text(20,y0-5,"** CImg %u.%u.%u Samples **",grey,0,1,22,
+    fore.assign(back.width(),50,1,1,0).draw_text(20,y0-5,"** CImg %u.%u.%u Samples **",grey,0,1,24,
                                                 cimg_version/100,(cimg_version/10)%10,cimg_version%10);
     (fore+=fore.get_dilate(3).dilate(3)).resize(-100,-100,1,3);
     cimg_forXY(fore,x,y)
